% QR metoda  
%
% Poziv funkcije: [Q,R,v] = ku_er(A,tol)
%
% Argumenti funkcije su :
%   A - matrica dimenzije NxN
%   tol - zadata tacnost

% Funkcija vraca:
%   Q i R - unitarna i gornje trougaona matrica td. An=QR
%   v - vektor sopstvenih vrednosti matrice A dobijenih QR metodom

function [Q,R,v] = ku_er(A,tol)

v=diag(A);
while 1
    [Q,R]=qrhouse1(A);
    %Ugradjena funkcija: [Q,R]=qr(A)
    A=R*Q;
    M=max(abs(v-diag(A)));
    v=diag(A);
    if M<tol break; 
    end
end
        
    
